"""
astLib - python astronomy modules

(c) 2007-2012 Matt Hilton

(c) 2013-2020 Matt Hilton & Steven Boada

U{http://astlib.sourceforge.net}

See the README file for information on usage and installation.
See the LICENSE file for information on distribution.

"""

__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
__version__ = '0.11.5'
